@@ -1,20 +1,18 @@
-/*
- * Copyright (C) 2010-2015 Joel Rosdahl
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 3 of the License, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
+// Copyright (C) 2010-2016 Joel Rosdahl
+//
+// This program is free software; you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option)
+// any later version.
+//
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+// more details.
+//
+// You should have received a copy of the GNU General Public License along with
+// this program; if not, write to the Free Software Foundation, Inc., 51
+// Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "ccache.h"
 #include "compopt.h"
@@ -36,6 +34,7 @@ static const struct compopt compopts[] = {
 	{"--save-temps",    TOO_HARD},
 	{"--serialize-diagnostics", TAKES_ARG | TAKES_PATH},
 	{"-A",              TAKES_ARG},
+	{"-B",              TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
 	{"-D",              AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG},
 	{"-E",              TOO_HARD},
 	{"-F",              AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
@@ -47,6 +46,7 @@ static const struct compopt compopts[] = {
 	{"-MM",             TOO_HARD},
 	{"-MQ",             TAKES_ARG},
 	{"-MT",             TAKES_ARG},
+	{"-P",              TOO_HARD},
 	{"-U",              AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG},
 	{"-V",              TAKES_ARG},
 	{"-Xassembler",     TAKES_ARG},
@@ -58,28 +58,31 @@ static const struct compopt compopts[] = {
 	{"-b",              TAKES_ARG},
 	{"-fmodules",       TOO_HARD},
 	{"-fno-working-directory", AFFECTS_CPP},
-	{"-fplugin=libcc1plugin", TOO_HARD}, /* interaction with GDB */
+	{"-fplugin=libcc1plugin", TOO_HARD}, // interaction with GDB
 	{"-frepo",          TOO_HARD},
+	{"-fstack-usage",   TOO_HARD},
 	{"-fworking-directory", AFFECTS_CPP},
-	{"-idirafter",      AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
+	{"-idirafter",      AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
 	{"-iframework",     AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
-	{"-imacros",        AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-imultilib",      AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-include",        AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-include-pch",    AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-install_name",   TAKES_ARG}, /* Darwin linker option */
-	{"-iprefix",        AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-iquote",         AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-isysroot",       AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-isystem",        AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-iwithprefix",    AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
-	{"-iwithprefixbefore", AFFECTS_CPP | TAKES_ARG | TAKES_PATH},
+	{"-imacros",        AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-imultilib",      AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-include",        AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-include-pch",    AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-install_name",   TAKES_ARG}, // Darwin linker option
+	{"-iprefix",        AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-iquote",         AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-isysroot",       AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-isystem",        AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-iwithprefix",    AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
+	{"-iwithprefixbefore",
+	 AFFECTS_CPP | TAKES_ARG | TAKES_CONCAT_ARG | TAKES_PATH},
 	{"-nostdinc",       AFFECTS_CPP},
 	{"-nostdinc++",     AFFECTS_CPP},
 	{"-remap",          AFFECTS_CPP},
 	{"-save-temps",     TOO_HARD},
+	{"-stdlib=",        AFFECTS_CPP | TAKES_CONCAT_ARG},
 	{"-trigraphs",      AFFECTS_CPP},
-	{"-u",              TAKES_ARG},
+	{"-u",              TAKES_ARG | TAKES_CONCAT_ARG},
 };
 
 
@@ -119,7 +122,7 @@ find_prefix(const char *option)
 	         sizeof(compopts[0]), compare_prefix_compopts);
 }
 
-/* Runs fn on the first two characters of option. */
+// Runs fn on the first two characters of option.
 bool
 compopt_short(bool (*fn)(const char *), const char *option)
 {
@@ -129,12 +132,11 @@ compopt_short(bool (*fn)(const char *), const char *option)
 	return retval;
 }
 
-/* For test purposes. */
+// For test purposes.
 bool
 compopt_verify_sortedness(void)
 {
-	size_t i;
-	for (i = 1; i < sizeof(compopts)/sizeof(compopts[0]); i++) {
+	for (size_t i = 1; i < sizeof(compopts)/sizeof(compopts[0]); i++) {
 		if (strcmp(compopts[i-1].name, compopts[i].name) >= 0) {
 			fprintf(stderr,
 			        "compopt_verify_sortedness: %s >= %s\n",
@@ -181,22 +183,19 @@ compopt_takes_arg(const char *option)
 	return co && (co->type & TAKES_ARG);
 }
 
-/* Determines if argument takes a concatentated argument by comparing prefixes.
- */
 bool
 compopt_takes_concat_arg(const char *option)
 {
-	const struct compopt *co = find_prefix(option);
+	const struct compopt *co = find(option);
 	return co && (co->type & TAKES_CONCAT_ARG);
 }
 
-/* Determines if the prefix of the option matches any option and affects the
- * preprocessor.
- */
+// Determines if the prefix of the option matches any option and affects the
+// preprocessor.
 bool
 compopt_prefix_affects_cpp(const char *option)
 {
-	/* prefix options have to take concatentated args */
+	// Prefix options have to take concatentated args.
 	const struct compopt *co = find_prefix(option);
 	return co && (co->type & TAKES_CONCAT_ARG) && (co->type & AFFECTS_CPP);
 }
